# This file was auto-generated by Fern from our API Definition.

import typing

FinetuningState = typing.Union[
    typing.Literal["not_started", "queued", "fine_tuning", "fine_tuned", "failed", "delayed"], typing.Any
]
